@@ -1,10 +1,11 @@
 from db import db
+from libK.kernel import kernel
 
 __author__ = 'negash'
 
 
 def get_kernel(database):
-    configs = db.s('z', "SELECT * FROM pipeline_config." + database)
+    configs = db.s('z', "SELECT * FROM " + kernel['config'] + "." + database)
 
     if 'key' in configs[0]:
         tmp = {}
